<div class="geoposition-widget" data-map-widget-height="{{ config.map_widget_height }}" data-map-options="{{ config.map_options }}" data-marker-options="{{ config.marker_options }}">
    <table>
        <tr>
            <td>{{ latitude.label|capfirst }}</td>
            <td>{{ latitude.html }}</td>
        </tr>
        <tr>
            <td>{{ longitude.label|capfirst }}</td>
            <td>{{ longitude.html }}</td>
        </tr>
    </table>
</div>
