.geoposition-widget {
    overflow: hidden;
}

.geoposition-map {
    position: relative;
    margin: 6px 0;
    clear: both;
}

.geoposition-widget table {
    float: left;
    border: 0;
    margin-bottom: 8px;
}

.geoposition-widget td {
    border: 0;
    padding: 0;
    padding-right: 5px;
    vertical-align: middle;
}

.geoposition-search {
    width: 30%;
}

.geoposition-search input {
    width: 100%;
}

.geoposition-address {
    float: left;
    text-align: left;
}

.geoposition-search {
    float: right;
    text-align: left;
}

.geoposition-results {
    position: absolute;
    z-index: 1;
    margin: 4px 0 0 0 !important;
    padding: 0 !important;
    background: white;
    border: 1px solid #eee;
    -webkit-box-shadow: 2px 2px 4px rgba(0,0,0,0.5);
    -moz-box-shadow: 2px 2px 4px rgba(0,0,0,0.5);
    box-shadow: 2px 2px 4px rgba(0,0,0,0.5);
}

.geoposition-results li {
    list-style: none;
    padding: 4px 8px;
    border-top: 1px dotted #eee;
    cursor: pointer;
}

.geoposition-results li:hover {
    background-color: #eee;
}
.geoposition-results li:first-child {
    border-top: 0;
}
